pub struct DevtoolSettings {
pub show_layout: bool,
pub highlight_hover: bool,
}Expand description
Configuration for debug overlays and other debugging tools
Fields
show_layout: boolOutline elements with different border colors depending on inner display style of that element
highlight_hover: boolRender browser-style colored overlay showing the content-box, padding, border, and margin of the hovered element
Implementations
Sourceimpl DevtoolSettings
impl DevtoolSettings
Sourcepub fn toggle_show_layout(&mut self)
pub fn toggle_show_layout(&mut self)
Toggle the show_layout setting
Sourcepub fn toggle_highlight_hover(&mut self)
pub fn toggle_highlight_hover(&mut self)
Toggle the highlight_hover setting