pub trait NetHandler<Data>:
Send
+ Sync
+ 'static {
// Required method
fn bytes(
self: Box<Self>,
doc_id: usize,
bytes: Bytes,
callback: Arc<dyn NetCallback<Data>>,
);
}Expand description
A type that parses raw bytes from a network request into a Data and then calls the NetCallack with the result.